# reboost

![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/legend-exp/reboost?logo=git)
[![GitHub Workflow Status](https://img.shields.io/github/checks-status/legend-exp/reboost/main?label=main%20branch&logo=github)](https://github.com/legend-exp/reboost/actions)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Codecov](https://img.shields.io/codecov/c/github/legend-exp/reboost?logo=codecov)](https://app.codecov.io/gh/legend-exp/reboost)
![GitHub issues](https://img.shields.io/github/issues/legend-exp/reboost?logo=github)
![GitHub pull requests](https://img.shields.io/github/issues-pr/legend-exp/reboost?logo=github)
![License](https://img.shields.io/github/license/legend-exp/reboost)
[![Read the Docs](https://img.shields.io/readthedocs/reboost?logo=readthedocs)](https://reboost.readthedocs.io)

_reboost_ is a package to post-process
[remage](https://remage.readthedocs.io/en/stable/) simulations. Post processing
is the step of applying a detector response model to the (idealised) _remage_ /
_Geant4_ simulations to ''boost" them allowing comparison to data.

_reboost_ provides tools to:

- apply a HPGe detector response model to the simulations,
- dedicated tools to generate optical maps,
- functionality to control the full post-processing chain with configuration
  files.

For more information see our dedicated
[documentation](https://reboost.readthedocs.io/en/stable/)!
